@@ -50,6 +50,7 @@ POSSIBILITY OF SUCH DAMAGE.
 #include <boost/tuple/tuple.hpp>
 #include <boost/unordered_map.hpp>
 #include <boost/optional.hpp>
+#include <boost/noncopyable.hpp>
 
 #ifdef TORRENT_USE_OPENSSL
 // there is no forward declaration header for asio
@@ -160,6 +161,8 @@ namespace libtorrent
 
 		boost::uint32_t key;
 		int num_want;
+
+		address_v4 ipv4;
 #if TORRENT_USE_IPV6
 		address_v6 ipv6;
 #endif
